.. nodoctest

Polyhedron exchange transformations (PETs) and induced transformations
======================================================================

.. automodule:: slabbe.polyhedron_exchange_transformation
   :members:
   :undoc-members:
   :show-inheritance:
   

